import type { EquTrialVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';


enum Api {
  equTrialExport = '/eims/equTrial/export',
  equTrialList = '/eims/equTrial/list',
  root = '/eims/equTrial'
}



/**
 * 查询设备试产记录列表
 * @param query
 * @returns {*}
 */

export function listEquTrial(params?: any) {
  return requestClient.get<EquTrialVO[]>(Api.equTrialList, { params });
}


/**
 * 查询设备试产记录详细
 * @param trialId
 */
export function getEquTrial(trialId: ID) {
  return requestClient.get<EquTrialVO>(`${Api.root}/${trialId}`);
}

/**
 * 新增设备试产记录
 * @param data
 */
export function addEquTrial(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改设备试产记录
 * @param data
 */
export function updateEquTrial(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除设备试产记录
 * @param trialId
 */
export function delEquTrial(trialId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${trialId}`);
}
/**
 * 导出
 * @param
 */
export function equTrialExport(data: any) {
  return commonExport(Api.equTrialExport, data);
}
